// ZEIT.H                           Schweitzer                       11.10.2011
// ----------------------------------------------------------------------------

// Programmfunktion: Zeitverzgerungs-Funktionen

// ----------------------------------------------------------------------------

// Der Takt des Mikrocontrollers bestimmt die Geschwindigkeit, mit der die
// Befehle verarbeitet werden.
// Mit der Prprozessor-Anweisung #define wird der Variablen cpu_clock der
// Wert des MC-Taktes in Hertz zugewiesen. Aus diesem Wert wird der Faktor
// ermittelt, der fr eine Millisekunde in der inneren for-Schleife bentigt
// wird.

// ============================================================================

// ----------------------------------------------------------------------------
// Definitionen
// ----------------------------------------------------------------------------

#ifndef ZEIT	// Wenn nicht definiert, ist ZEIT.H nicht eingebunden
#define ZEIT	// Definition von "ZEIT"

// ----------------------------------------------------------------------------
// Bentigte Headerdateien
// ----------------------------------------------------------------------------

#include "CPU_CLOCK.H"	// Taktfrequenz des Mikrocontrollers

// ----------------------------------------------------------------------------
// Funktionsprototypen
// ----------------------------------------------------------------------------

void zeit    (unsigned long int);
void zeit_us (unsigned long int);					

// ----------------------------------------------------------------------------
// Zeitverzgerung in Millisekunden (Definition in "CPU_CLOCK.H")
// ----------------------------------------------------------------------------

void zeit (unsigned long int warten)
{

	unsigned long int i, j;							// lokale Variablen
	
	for (i = 0; i < warten; i++)					// warten
		for (j = 0; j < MILLISEKUNDE; j++)
		{
			asm volatile ("NOP");					// Inline-ASM: leerer Befehl
		}

}

// ----------------------------------------------------------------------------
//	Zeitverzgerung in (ca.) Mikrosekunden (Definition in "CPU_CLOCK.H")
// ----------------------------------------------------------------------------

void zeit_us (unsigned long int warten)  		// Verzgerung ca. (zeit) us
{

	unsigned long int i, j;

   for (i = 0; i < warten; i++)
   	for (j = 0; j < MIKROSEKUNDE; j++)	   // Prozessor beschftigen
	   {
		   asm volatile("NOP");						// Inline-ASM: leerer Befehl
	   }
      											
}

// ----------------------------------------------------------------------------

#endif

// ============================================================================
